@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 
@@ -17,8 +17,10 @@ XSLoader::load( __PACKAGE__, $VERSION );
 
 # So that feature->import will work in `class`
 require feature;
-require experimental;
-require indirect;
+if( $] >= 5.020 ) {
+   require experimental;
+   require indirect;
+}
 
 =head1 NAME
 
@@ -160,10 +162,6 @@ Subclassing. Single-inheritence is easier than multi so maybe that first.
 
 =item *
 
-Detect and croak on attempts to invoke C<method> subs on non-instances.
-
-=item *
-
 Experiment with C<CvOUTSIDE> or other techniques as a way to set up the
 per-method pad, and consider if we can detect which slots are in use that way
 to improve method-enter performance.
@@ -178,6 +176,10 @@ Default expressions
 
 A way to request generated accessors - ro or rw.
 
+=item *
+
+Work out why C<no indirect> doesn't appear to work properly before perl 5.20.
+
 =back
 
 =cut
